@@ -85,7 +85,7 @@ where
     }
 }
 
-impl<'a, T> Copy for Reader<'a, T> where T: crate::traits::Owned {}
+impl<T> Copy for Reader<'_, T> where T: crate::traits::Owned {}
 
 impl<'a, T> IndexMove<u32, Result<T::Reader<'a>>> for Reader<'a, T>
 where
@@ -182,7 +182,7 @@ where
     }
 }
 
-impl<'a, T> Builder<'a, T>
+impl<T> Builder<'_, T>
 where
     T: crate::traits::Owned,
 {
@@ -287,7 +287,7 @@ impl<'a, T: crate::traits::Owned> From<Reader<'a, T>> for crate::dynamic_value::
 impl<'a, T: crate::traits::Owned> crate::dynamic_value::DowncastReader<'a> for Reader<'a, T> {
     fn downcast_reader(v: crate::dynamic_value::Reader<'a>) -> Self {
         let dl: crate::dynamic_list::Reader = v.downcast();
-        assert!(dl.element_type().may_downcast_to(T::introspect()));
+        assert!(dl.element_type().loose_equals(T::introspect()));
         Reader {
             reader: dl.reader,
             marker: core::marker::PhantomData,
@@ -307,7 +307,7 @@ impl<'a, T: crate::traits::Owned> From<Builder<'a, T>> for crate::dynamic_value:
 impl<'a, T: crate::traits::Owned> crate::dynamic_value::DowncastBuilder<'a> for Builder<'a, T> {
     fn downcast_builder(v: crate::dynamic_value::Builder<'a>) -> Self {
         let dl: crate::dynamic_list::Builder = v.downcast();
-        assert!(dl.element_type().may_downcast_to(T::introspect()));
+        assert!(dl.element_type().loose_equals(T::introspect()));
         Builder {
             builder: dl.builder,
             marker: core::marker::PhantomData,
@@ -315,7 +315,7 @@ impl<'a, T: crate::traits::Owned> crate::dynamic_value::DowncastBuilder<'a> for
     }
 }
 
-impl<'a, T: crate::traits::Owned> core::fmt::Debug for Reader<'a, T> {
+impl<T: crate::traits::Owned> core::fmt::Debug for Reader<'_, T> {
     fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
         core::fmt::Debug::fmt(
             &::core::convert::Into::<crate::dynamic_value::Reader<'_>>::into(*self),
