@@ -88,13 +88,13 @@ impl<'a, T: PrimitiveElement> FromPointerReader<'a> for Reader<'a, T> {
     }
 }
 
-impl<'a, T: PrimitiveElement> IndexMove<u32, T> for Reader<'a, T> {
+impl<T: PrimitiveElement> IndexMove<u32, T> for Reader<'_, T> {
     fn index_move(&self, index: u32) -> T {
         self.get(index)
     }
 }
 
-impl<'a, T: PrimitiveElement> Reader<'a, T> {
+impl<T: PrimitiveElement> Reader<'_, T> {
     /// Gets the `T` at position `index`. Panics if `index` is greater than or
     /// equal to `len()`.
     pub fn get(&self, index: u32) -> T {
@@ -248,7 +248,7 @@ impl<'a, T: PrimitiveElement> FromPointerBuilder<'a> for Builder<'a, T> {
     }
 }
 
-impl<'a, T: PrimitiveElement> Builder<'a, T> {
+impl<T: PrimitiveElement> Builder<'_, T> {
     /// Gets the `T` at position `index`. Panics if `index` is greater than or
     /// equal to `len()`.
     pub fn get(&self, index: u32) -> T {
@@ -349,7 +349,7 @@ impl<'a, T: PrimitiveElement + crate::introspect::Introspect>
 {
     fn downcast_reader(v: crate::dynamic_value::Reader<'a>) -> Self {
         let dl: crate::dynamic_list::Reader = v.downcast();
-        assert!(dl.element_type().may_downcast_to(T::introspect()));
+        assert!(dl.element_type().loose_equals(T::introspect()));
         Reader {
             reader: dl.reader,
             marker: marker::PhantomData,
@@ -373,7 +373,7 @@ impl<'a, T: PrimitiveElement + crate::introspect::Introspect>
 {
     fn downcast_builder(v: crate::dynamic_value::Builder<'a>) -> Self {
         let dl: crate::dynamic_list::Builder = v.downcast();
-        assert!(dl.element_type().may_downcast_to(T::introspect()));
+        assert!(dl.element_type().loose_equals(T::introspect()));
         Builder {
             builder: dl.builder,
             marker: marker::PhantomData,
@@ -381,8 +381,8 @@ impl<'a, T: PrimitiveElement + crate::introspect::Introspect>
     }
 }
 
-impl<'a, T: Copy + PrimitiveElement + crate::introspect::Introspect> core::fmt::Debug
-    for Reader<'a, T>
+impl<T: Copy + PrimitiveElement + crate::introspect::Introspect> core::fmt::Debug
+    for Reader<'_, T>
 {
     fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
         core::fmt::Debug::fmt(
